@@ -60,12 +60,12 @@ def monkey_patch_make_context():
 def strcsv2tuple(strcsv, lower=False):
     if isinstance(strcsv, tuple):
         # Crazy!! but click==8.0.1 is sending "value" transformed
-        strcsv = ','.join(strcsv)
+        strcsv = ",".join(strcsv)
     strcsv = strcsv and strcsv.strip() or ""
     if not strcsv:
         return ()
     items = ()
-    for item in strcsv.split(','):
+    for item in strcsv.split(","):
         item = item.strip()
         if lower:
             item = item.lower()
@@ -74,11 +74,11 @@ def strcsv2tuple(strcsv, lower=False):
 
 
 class CSVChoice(click.Choice):
-    envvar_list_splitter = ','
+    envvar_list_splitter = ","
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.name += ' CSV'
+        self.name += " CSV"
 
     def convert(self, value, param, ctx):
         values = ()
@@ -89,12 +89,26 @@ class CSVChoice(click.Choice):
         return values
 
 
-class CSVPath(click.Path):
-    envvar_list_splitter = ','
+class CSVStringParamType(click.types.StringParamType):
+    envvar_list_splitter = ","
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.name += ' CSV'
+        self.name += " CSV"
+
+    def convert(self, value, param, ctx):
+        values = ()
+        for v in strcsv2tuple(value):
+            values += (super().convert(v, param, ctx),)
+        return values
+
+
+class CSVPath(click.Path):
+    envvar_list_splitter = ","
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.name += " CSV"
 
     def convert(self, value, param, ctx):
         values = ()
@@ -123,9 +137,26 @@ def merge_tuples(ctx, param, value):
     return values
 
 
+def precommit_hooks_type_callback(ctx, param, value):
+    """If value is 'all' so all the option will be assigned
+    If value has prefix '-' so that option will be removed
+    value = 'all,-fix' will return 'mandatory,optional,experimental'
+    """
+    values = merge_tuples(ctx, param, value)
+    values = set(values)
+    all_values = {i for i in param.type.choices if not i.startswith("-") and not i == "all"}
+    if "all" in values:
+        values -= {"all"}
+        values |= all_values
+    for v in values.copy():
+        if v.startswith("-"):
+            values -= {v, v[1:]}
+    return tuple(values)
+
+
 new_extra_kwargs = {}
 try:
-    if tuple(map(int, click.__version__.split('.'))) >= (7, 0):
+    if tuple(map(int, click.__version__.split("."))) >= (7, 0):
         # It is only compatible for click >= 7.0 but it is not a big deal if it is not enabled
         # For record, dockerv image is using click 6.6 version
         new_extra_kwargs["show_envvar"] = True
@@ -135,6 +166,10 @@ except (TypeError, ValueError, AttributeError):  # pylint: disable=except-pass
 monkey_patch_make_context()
 
 
+PRECOMMIT_HOOKS_TYPE = ["mandatory", "optional", "fix", "experimental"]
+PRECOMMIT_HOOKS_TYPE += ["all"] + ["-%s" % i for i in PRECOMMIT_HOOKS_TYPE]
+
+
 @click.command()
 # click 6.6 used in dockerv doesn't support to use envvar for click.argument :(
 # More info https://github.com/pallets/click/issues/714 workaround using option instead.
@@ -151,16 +186,29 @@ monkey_patch_make_context()
     **new_extra_kwargs,
 )
 @click.option(
-    "--overwrite",
-    "-w",
-    envvar="PRECOMMIT_OVERWRITE_CONFIG_FILES",
-    default=True,
+    "--no-overwrite",
+    envvar="PRECOMMIT_NO_OVERWRITE_CONFIG_FILES",
+    type=click.BOOL,
+    is_flag=True,
+    default=False,
     show_default=True,
     help="Overwrite configuration files. "
     "\f\n*If True, existing configuration files into the project will be overwritten. "
     "\f\n*If False, then current files will be used, if they exist.",
     **new_extra_kwargs,
 )
+@click.option(
+    "--fail-optional",
+    envvar="PRECOMMIT_FAIL_OPTIONAL",
+    type=click.BOOL,
+    default=False,
+    is_flag=True,
+    show_default=True,
+    help="Change the exit_code for 'optional' precommit-hooks-type."
+    "\f\n*If this flag is enabled so the exit_code will be -1 (error) if 'optional' fails."
+    "\f\n*If it is disabled (by default), exit_code will be 0 (successful) even if 'optional' fails.",
+    **new_extra_kwargs,
+)
 @click.option(
     "--exclude-autofix",
     "-x",
@@ -182,43 +230,55 @@ monkey_patch_make_context()
     **new_extra_kwargs,
 )
 @click.option(
-    "--disable-pylint-checks",
-    '-d',
-    type=str,
+    "--pylint-disable-checks",
+    "-d",
+    type=CSVStringParamType(),
     callback=merge_tuples,
-    envvar="DISABLE_PYLINT_CHECKS",
+    envvar="PYLINT_DISABLE_CHECKS",
     help="Pylint checks to disable, separated by commas.",
     **new_extra_kwargs,
 )
 @click.option(
-    "--autofix",
-    "-f",
-    envvar="PRECOMMIT_AUTOFIX",
+    "--skip-string-normalization",
+    "-S",
+    envvar="BLACK_SKIP_STRING_NORMALIZATION",
     is_flag=True,
     default=False,
     show_default=True,
-    help="Run pre-commit with autofix configuration to change the source code."
-    "\f\nOverwrite '-t mandatory,optional,fix'",
+    help="If '-t fix' is enabled, "
+    "don't normalize string quotes or prefixes '' -> \"\""
+    "\f\nThis parameter is related to 'black' hook",
     **new_extra_kwargs,
 )
 @click.option(
     "--precommit-hooks-type",
     "-t",
-    type=CSVChoice(["mandatory", "optional", "fix", "all"]),
-    default=["mandatory", "optional"],
+    type=CSVChoice(PRECOMMIT_HOOKS_TYPE),
+    default=["all", "-fix"],
     multiple=True,
-    callback=merge_tuples,
+    callback=precommit_hooks_type_callback,
     show_default=True,
     envvar="PRECOMMIT_HOOKS_TYPE",
     help="Pre-commit configuration file to run hooks, separated by commas. "
+    "\f\nprefix '-' means that the option will be removed. "
     "\f\n*Mandatory: Stable hooks that needs to be fixed (Affecting build status). "
-    "\f\n*Optional: Optional hooks that could be fixed later. (No affects build status). "
+    "\f\n*Optional: Optional hooks that could be fixed later. "
+    "(No affects build status almost '--fail-optional' is set). "
+    "\f\n*Experimental: Experimental hooks that only to test. (No affects build status). "
     "\f\n*Fix: Hooks auto fixing source code (Affects build status). "
     "\f\n*All: All configuration files to run hooks. ",
     **new_extra_kwargs,
 )
-def main(paths, overwrite, exclude_autofix, exclude_lint, disable_pylint_checks, autofix, precommit_hooks_type):
+@click.option(
+    "--install",
+    type=click.BOOL,
+    is_flag=True,
+    default=False,
+    help="Install the pre-commit script"
+    "\f\nUsing this option a '.git/hooks/pre-commit' will be created"
+    "\f\nNow your command 'git commit' will run 'pre-commit-vauxoo' before to commit",
+    **new_extra_kwargs,
+)
+def main(*args, **kwargs):
     """pre-commit-vauxoo run pre-commit with custom validations and configuration files"""
-    pre_commit_vauxoo.main(
-        paths, overwrite, exclude_autofix, exclude_lint, disable_pylint_checks, autofix, precommit_hooks_type
-    )
+    pre_commit_vauxoo.main(*args, **kwargs)
