@@ -1,6 +1,7 @@
 import logging
 import os
 import re
+import shutil
 import subprocess
 import sys
 
@@ -29,7 +30,13 @@ def get_files(path):
 
 
 def copy_cfg_files(
-    precommit_config_dir, repo_dirname, overwrite, exclude_lint, disable_pylint_checks, exclude_autofix
+    precommit_config_dir,
+    repo_dirname,
+    no_overwrite,
+    exclude_lint,
+    pylint_disable_checks,
+    exclude_autofix,
+    skip_string_normalization,
 ):
     exclude_lint_regex = ""
     exclude_autofix_regex = ""
@@ -55,7 +62,7 @@ def copy_cfg_files(
             # if it is not a file skip
             continue
         dst = os.path.join(repo_dirname, fname)
-        if not overwrite and os.path.isfile(dst):
+        if no_overwrite and os.path.isfile(dst):
             # Use the custom files defined in the repo
             _logger.warning("Using custom file %s", dst)
             continue
@@ -69,8 +76,13 @@ def copy_cfg_files(
                     if fname == ".pre-commit-config-autofix.yaml" and exclude_autofix:
                         _logger.info("Applying EXCLUDE_AUTOFIX=%s to %s", exclude_autofix, dst)
                         line += "    %s\n" % exclude_autofix_regex
-                if disable_pylint_checks and fname.startswith(".pre-commit-config") and "--disable=R0000" in line:
-                    line = line.replace("R0000", ','.join(disable_pylint_checks))
+                if pylint_disable_checks and fname.startswith(".pre-commit-config") and "--disable=R0000" in line:
+                    _logger.info(
+                        "Disabling the following pylint checks (PYLINT_DISABLE_CHECKS): %s", pylint_disable_checks
+                    )
+                    line = line.replace("R0000", ",".join(pylint_disable_checks))
+                if fname == "pyproject.toml" and line.startswith("skip-string-normalization"):
+                    line = "skip-string-normalization=%s" % (skip_string_normalization and "true" or "false")
                 fdst.write(line)
 
 
@@ -97,7 +109,7 @@ def envfile2envdict(repo_dirname, source_file="variables.sh", no_overwrite_envir
 
 
 def subprocess_call(command, *args, **kwargs):
-    cmd_str = ' '.join(command)
+    cmd_str = " ".join(command)
     _logger.debug("Running command: %s", cmd_str)
     return subprocess.call(command, *args, **kwargs)
 
@@ -105,13 +117,15 @@ def subprocess_call(command, *args, **kwargs):
 # There are a lot of if validations in this method. It is expected for now.
 # pylint: disable=too-complex
 def main(
-    include_lint,
-    overwrite,
+    paths,
+    no_overwrite,
     exclude_autofix,
     exclude_lint,
-    disable_pylint_checks,
-    autofix,
+    pylint_disable_checks,
     precommit_hooks_type,
+    fail_optional,
+    install,
+    skip_string_normalization,
     do_exit=True,
 ):
     repo_dirname = get_repo()
@@ -119,41 +133,46 @@ def main(
 
     root_dir = os.path.abspath(os.path.dirname(__file__))
 
+    if install:
+        git_hook_pre_commit_src = os.path.join(root_dir, "git_hook_pre_commit")
+        git_hook_pre_commit_dest = os.path.join(repo_dirname, ".git", "hooks", "pre-commit")
+        _logger.info("pre-commit installed at %s", git_hook_pre_commit_dest)
+        shutil.copy(git_hook_pre_commit_src, git_hook_pre_commit_dest)
+        if do_exit:
+            sys.exit(0)
+        return
+
     precommit_config_dir = os.path.join(root_dir, "cfg")
 
     copy_cfg_files(
         precommit_config_dir,
         repo_dirname,
-        overwrite,
+        no_overwrite,
         exclude_lint,
-        disable_pylint_checks,
+        pylint_disable_checks,
         exclude_autofix,
+        skip_string_normalization,
     )
-    if autofix:
-        precommit_hooks_type = ("mandatory", "optional", "fix")
-    elif not precommit_hooks_type:
-        precommit_hooks_type = ("mandatory", "optional")
-
     _logger.info("Installing pre-commit hooks")
     cmd = ["pre-commit", "install-hooks", "--color=always"]
     pre_commit_cfg_mandatory = os.path.join(repo_dirname, ".pre-commit-config.yaml")
     pre_commit_cfg_optional = os.path.join(repo_dirname, ".pre-commit-config-optional.yaml")
     pre_commit_cfg_autofix = os.path.join(repo_dirname, ".pre-commit-config-autofix.yaml")
-    if "mandatory" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "mandatory" in precommit_hooks_type:
         subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
-    if "optional" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "optional" in precommit_hooks_type:
         subprocess_call(cmd + ["-c", pre_commit_cfg_optional])
-    if "fix" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "fix" in precommit_hooks_type:
         subprocess_call(cmd + ["-c", pre_commit_cfg_autofix])
 
     status = 0
     cmd = ["pre-commit", "run", "--color=always"]
     if cwd != repo_dirname:
         cwd_short = os.path.relpath(cwd, repo_dirname)
-        if include_lint:
+        if paths:
             _logger.warning(
                 "Ignored path configured '%s'. Use 'cd %s' and run the same command again to use configured path",
-                ','.join(include_lint),
+                ",".join(paths),
                 repo_dirname,
             )
         _logger.warning("Running in current directory '%s'", cwd_short)
@@ -161,64 +180,69 @@ def main(
         if not files:
             raise UserWarning("Not files detected in current path %s" % cwd_short)
         cmd.extend(["--files"] + files)
-    elif include_lint and include_lint != ('.',):
-        _logger.info("Running only for INCLUDE_LINT=%s", include_lint)
+    elif paths and paths != (".",):
+        _logger.info("Running only for INCLUDE_LINT=%s", paths)
         included_files = []
-        for included_path in include_lint:
+        for included_path in paths:
             included_files += get_files(included_path) or (included_path,)
         cmd.extend(["--files"] + included_files)
     else:
         cmd.append("--all")
     all_status = {}
 
-    if "fix" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "fix" in precommit_hooks_type:
         _logger.info("%s AUTOFIX CHECKS %s", "-" * 25, "-" * 25)
         _logger.info("Running autofix checks (affect status build but you can autofix them locally)")
         autofix_status = subprocess_call(cmd + ["-c", pre_commit_cfg_autofix])
         status += autofix_status
-        test_name = 'Autofix checks'
-        all_status[test_name] = {'status': autofix_status}
+        test_name = "Autofix checks"
+        all_status[test_name] = {"status": autofix_status}
         if autofix_status != 0:
             _logger.error("%s reformatted", test_name)
-            all_status[test_name]['level'] = logging.ERROR
-            all_status[test_name]['status_msg'] = "Reformatted"
+            all_status[test_name]["level"] = logging.ERROR
+            all_status[test_name]["status_msg"] = "Reformatted"
         else:
             _logger.info("%s passed!", test_name)
-            all_status[test_name]['level'] = logging.INFO
-            all_status[test_name]['status_msg'] = "Passed"
+            all_status[test_name]["level"] = logging.INFO
+            all_status[test_name]["status_msg"] = "Passed"
         _logger.info("-" * 66)
 
-    if "mandatory" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "mandatory" in precommit_hooks_type:
         _logger.info("%s MANDATORY CHECKS %s", "*" * 25, "*" * 25)
         _logger.info("Running mandatory checks (affect status build)")
         mandatory_status = subprocess_call(cmd + ["-c", pre_commit_cfg_mandatory])
         status += mandatory_status
-        test_name = 'Mandatory checks'
-        all_status[test_name] = {'status': mandatory_status}
-        if status != 0:
+        test_name = "Mandatory checks"
+        all_status[test_name] = {"status": mandatory_status}
+        if mandatory_status != 0:
             _logger.error("%s failed", test_name)
-            all_status[test_name]['level'] = logging.ERROR
-            all_status[test_name]['status_msg'] = "Failed"
+            all_status[test_name]["level"] = logging.ERROR
+            all_status[test_name]["status_msg"] = "Failed"
         else:
             _logger.info("%s passed!", test_name)
-            all_status[test_name]['level'] = logging.INFO
-            all_status[test_name]['status_msg'] = "Passed"
+            all_status[test_name]["level"] = logging.INFO
+            all_status[test_name]["status_msg"] = "Passed"
 
-    if "optional" in precommit_hooks_type or 'all' in precommit_hooks_type:
+    if "optional" in precommit_hooks_type:
         _logger.info("*" * 68)
         _logger.info("%s OPTIONAL CHECKS %s", "~" * 25, "~" * 25)
         _logger.info("Running optional checks (does not affect status build)")
         status_optional = subprocess_call(cmd + ["-c", os.path.join(repo_dirname, pre_commit_cfg_optional)])
-        test_name = 'Optional checks'
-        all_status[test_name] = {'status': status_optional}
-        if status_optional != 0:
+        test_name = "Optional checks"
+        all_status[test_name] = {"status": status_optional}
+        if status_optional != 0 and fail_optional:
+            _logger.error("Optional checks failed")
+            all_status[test_name]["level"] = logging.ERROR
+            all_status[test_name]["status_msg"] = "Failed"
+            status += status_optional
+        elif status_optional != 0:
             _logger.warning("Optional checks failed")
-            all_status[test_name]['level'] = logging.WARNING
-            all_status[test_name]['status_msg'] = "Failed"
+            all_status[test_name]["level"] = logging.WARNING
+            all_status[test_name]["status_msg"] = "Failed"
         else:
             _logger.info("Optional checks passed!")
-            all_status[test_name]['level'] = logging.INFO
-            all_status[test_name]['status_msg'] = "Passed"
+            all_status[test_name]["level"] = logging.INFO
+            all_status[test_name]["status_msg"] = "Passed"
         _logger.info("~" * 67)
 
     print_summary(all_status)
@@ -232,13 +256,13 @@ def print_summary(all_status):
     summary_msg.append("|" + "-" * 39)
     for test_name, test_result in all_status.items():
         outcome = (
-            logging_colored.colorized_msg(test_result['status_msg'], test_result['level'])
-            if test_result['status'] != 0
-            else logging_colored.colorized_msg(test_result['status_msg'], test_result['level'])
+            logging_colored.colorized_msg(test_result["status_msg"], test_result["level"])
+            if test_result["status"] != 0
+            else logging_colored.colorized_msg(test_result["status_msg"], test_result["level"])
         )
         summary_msg.append("| {:<28}{}".format(test_name, outcome))
     summary_msg.append("+" + "=" * 39)
-    _logger.info("Tests summary\n%s", '\n'.join(summary_msg))
+    _logger.info("Tests summary\n%s", "\n".join(summary_msg))
 
 
 if __name__ == "__main__":
